==> yabs-0.7.2.tar.bz2: yabs/trackback.php <==
<?php

/* trackback.php
 * =============
 *
 * Recives Trackback Links
 * Started: 2005-05-20
 * Edited: 2005-05-27
 * (c) 2005 yabs
 */
 
	require_once('inc/cfg.inc.php');
	require_once('inc/class.core.inc.php');
	$yabs = new yabs_core();
	require_once('inc/functions.inc.php');
	require_once('inc/class.mysql.inc.php');
	require_once('inc/class.spamfilter.inc.php');
	
	// +-----------------------------------------------------+
	// | mod_rewrite                                         |
	// +-----------------------------------------------------+
	if(!defined('MOD_REWRITE')){
		define('MOD_REWRITE', false);
	}
	/*
	if(MOD_REWRITE){
		make_get();
	}
	*/
	//Start a connection to the mysql server
	$db = new database($dbhost, $dbuser, $dbpass, $dbname);
    
    // +-----------------------------------------------------+
	// | Check if config is given and load it                |
	// +-----------------------------------------------------+
	$cfg_sql = "SELECT
					*
				FROM
					".$dbprefix."config
				LIMIT
					0, 1;";
	$cfg_res = $db->query($cfg_sql);
	if($db->numrows($cfg_res) == 0){
		$yabs->death_event('Can\'t load config.');
	}
	$config = $db->fetch($cfg_res);
	// +-----------------------------------------------------+
	// | Config-Code End                                     |
	// +-----------------------------------------------------+

	header("Content-type: text/xml");

	$return = "<?xml version=\"1.0\" encoding=\"iso-896-1\"?>\n";
	$return .= "<response>\n";
	$return .= "<error>{ERROR}</error>\n";
	$return .= "{MESSAGE}";
	$return .= "</response>";

	if(!empty($_GET['id']) && is_numeric($_GET['id'])){
		if(!empty($_POST['url'])){
			if(empty($_POST['blog_name'])) $_POST['blog_name'] = $_POST['url'];
			if(empty($_POST['title'])) $_POST['title'] = '-';
			if(empty($_POST['excerpt'])) $_POST['excerpt'] = '[...]';
			/*
			$check_sql = "	SELECT
								ID
							FROM
								".$mysql_prefix."trackback
							WHERE
								BlogID = '".trim($_GET['id'])."' and
								IP = '".$_SERVER['REMOTE_ADDR']."' and
								blog_name = '".trim($_POST['blog_name'])."';";
			*/
			$check_sql = "	SELECT
								ID
							FROM
								".$dbprefix."trackback
							WHERE
								BlogID = '".trim($_GET['id'])."' and
								url = '".trim($_POST['url'])."';";
			$check_result =$db->query($check_sql);
			
			if($db->numrows($check_result) == 0){
				$check_sql = "	SELECT
									nofeedback
								FROM
									".$dbprefix."blog
								WHERE
									ID = '".trim($_GET['id'])."';";
				$check_result = $db->query($check_sql);
				if($db->numrows($check_result) > 0){
					$check = $db->fetch($check_result);
					if(!$check['nofeedback']){
						$spam = false;
						if($config['urlscan'] == 1){
							$filter = new spamfilter();
							$host = gethostbyaddr($_SERVER['REMOTE_ADDR']);
							if(!$filter->urlscan($_POST['url'].' '.$_POST['excerpt'].' '.$_POST['title'].' '.$_POST['blog_name'].' '.$host)){
								$spam = true;
							}
						}
						if(!$spam){
							$tb_sql = "	INSERT INTO ".$dbprefix."trackback
											(BlogID,
											 IP,
											 blog_name,
											 title,
											 excerpt,
											 url,
											 date,
											 active
											)
										VALUES
											('".trim($_GET['id'])."',
											 '".$_SERVER['REMOTE_ADDR']."',
											 '".trim($_POST['blog_name'])."',
											 '".trim($_POST['title'])."',
											 '".trim($_POST['excerpt'])."',
											 '".trim($_POST['url'])."',
											 '".time()."',
											 '".!$config['activate_trackback']."'
											);";
							$db->query($tb_sql);
							$yabs->deletecachedentry(trim($_GET['id']));
							$return = str_replace('{ERROR}', '0', $return);
							$return = str_replace('{MESSAGE}', '', $return);
						}else{
							$return = str_replace('{ERROR}', '1', $return);
							$return = str_replace('{MESSAGE}', '<message>Sorry, but you have not passed the spamtest. If you think this is an error, please contact the administrator.</message>', $return);
						}
					}else{
						$return = str_replace('{ERROR}', '1', $return);
						$return = str_replace('{MESSAGE}', '<message>Sorry, but Trackbacks are not allowed for this entry.</message>', $return);
					}
				}else{
					$return = str_replace('{ERROR}', '1', $return);
					$return = str_replace('{MESSAGE}', '<message>Sorry, but i don\'t found this entry.</message>', $return);
				}
			}else{
				$return = str_replace('{ERROR}', '1', $return);
				$return = str_replace('{MESSAGE}', '<message>Sorry, but you have already send a trackback for this entry.</message>', $return);
			}
		}else{
			$return = str_replace('{ERROR}', '1', $return);
			$return = str_replace('{MESSAGE}', '<message>Sorry, but you have to send me your URL</message>', $return);
		}
	}else{
		$return = str_replace('{ERROR}', '1', $return);
		$return = str_replace('{MESSAGE}', '<message>Sorry, but I don\'t know which entry you mean</message>', $return);
	}
	
	print $return;
	
?>

==> yabs-0.7.3.tar.bz2: yabs/trackback.php <==
<?php

/* trackback.php
 * =============
 *
 * Recives Trackback Links
 * Started: 2005-05-20
 * Edited: 2005-05-27
 * (c) 2005 yabs
 */
 
	require_once('inc/cfg.inc.php');
	require_once('inc/class.core.inc.php');
	$yabs = new yabs_core();
	require_once('inc/functions.inc.php');
	require_once('inc/class.mysql.inc.php');
	require_once('inc/class.spamfilter.inc.php');
	
	// +-----------------------------------------------------+
	// | mod_rewrite                                         |
	// +-----------------------------------------------------+
	if(!defined('MOD_REWRITE')){
		define('MOD_REWRITE', false);
	}
	/*
	if(MOD_REWRITE){
		make_get();
	}
	*/
	//Start a connection to the mysql server
	$db = new database($dbhost, $dbuser, $dbpass, $dbname);
    
    // +-----------------------------------------------------+
	// | Check if config is given and load it                |
	// +-----------------------------------------------------+
	$cfg_sql = "SELECT
					*
				FROM
					".$dbprefix."config
				LIMIT
					0, 1;";
	$cfg_res = $db->query($cfg_sql);
	if($db->numrows($cfg_res) == 0){
		$yabs->death_event('Can\'t load config.');
	}
	$config = $db->fetch($cfg_res);
	// +-----------------------------------------------------+
	// | Config-Code End                                     |
	// +-----------------------------------------------------+

	header("Content-type: text/xml");

	$return = "<?xml version=\"1.0\" encoding=\"iso-896-1\"?>\n";
	$return .= "<response>\n";
	$return .= "<error>{ERROR}</error>\n";
	$return .= "{MESSAGE}";
	$return .= "</response>";

	if(!empty($_GET['id']) && is_numeric($_GET['id'])){
		if(!empty($_POST['url'])){
			if(empty($_POST['blog_name'])) $_POST['blog_name'] = $_POST['url'];
			if(empty($_POST['title'])) $_POST['title'] = '-';
			if(empty($_POST['excerpt'])) $_POST['excerpt'] = '[...]';
			/*
			$check_sql = "	SELECT
								ID
							FROM
								".$mysql_prefix."trackback
							WHERE
								BlogID = '".trim($_GET['id'])."' and
								IP = '".$_SERVER['REMOTE_ADDR']."' and
								blog_name = '".trim($_POST['blog_name'])."';";
			*/
			$check_sql = "	SELECT
								ID
							FROM
								".$dbprefix."trackback
							WHERE
								BlogID = '".trim($_GET['id'])."' and
								url = '".trim($_POST['url'])."';";
			$check_result =$db->query($check_sql);
			
			if($db->numrows($check_result) == 0){
				$check_sql = "	SELECT
									nofeedback
								FROM
									".$dbprefix."blog
								WHERE
									ID = '".trim($_GET['id'])."';";
				$check_result = $db->query($check_sql);
				if($db->numrows($check_result) > 0){
					$check = $db->fetch($check_result);
					if(!$check['nofeedback']){
						$spam = false;
						if($config['urlscan'] == 1){
							$filter = new spamfilter();
							$host = gethostbyaddr($_SERVER['REMOTE_ADDR']);
							if(!$filter->urlscan($_POST['url'].' '.$_POST['excerpt'].' '.$_POST['title'].' '.$_POST['blog_name'].' '.$host.' '.$_SERVER['REMOTE_ADDR'])){
								$spam = true;
							}
						}
						if(!$spam){
							$tb_sql = "	INSERT INTO ".$dbprefix."trackback
											(BlogID,
											 IP,
											 blog_name,
											 title,
											 excerpt,
											 url,
											 date,
											 active
											)
										VALUES
											('".trim($_GET['id'])."',
											 '".$_SERVER['REMOTE_ADDR']."',
											 '".trim($_POST['blog_name'])."',
											 '".trim($_POST['title'])."',
											 '".trim($_POST['excerpt'])."',
											 '".trim($_POST['url'])."',
											 '".time()."',
											 '".!$config['activate_trackback']."'
											);";
							$db->query($tb_sql);
							$yabs->deletecachedentry(trim($_GET['id']));
							$return = str_replace('{ERROR}', '0', $return);
							$return = str_replace('{MESSAGE}', '', $return);
						}else{
							$return = str_replace('{ERROR}', '1', $return);
							$return = str_replace('{MESSAGE}', '<message>Sorry, but you have not passed the spamtest. If you think this is an error, please contact the administrator.</message>', $return);
						}
					}else{
						$return = str_replace('{ERROR}', '1', $return);
						$return = str_replace('{MESSAGE}', '<message>Sorry, but Trackbacks are not allowed for this entry.</message>', $return);
					}
				}else{
					$return = str_replace('{ERROR}', '1', $return);
					$return = str_replace('{MESSAGE}', '<message>Sorry, but i don\'t found this entry.</message>', $return);
				}
			}else{
				$return = str_replace('{ERROR}', '1', $return);
				$return = str_replace('{MESSAGE}', '<message>Sorry, but you have already send a trackback for this entry.</message>', $return);
			}
		}else{
			$return = str_replace('{ERROR}', '1', $return);
			$return = str_replace('{MESSAGE}', '<message>Sorry, but you have to send me your URL</message>', $return);
		}
	}else{
		$return = str_replace('{ERROR}', '1', $return);
		$return = str_replace('{MESSAGE}', '<message>Sorry, but I don\'t know which entry you mean</message>', $return);
	}
	
	print $return;
	
?>
